==> pc2m-0.9.14.zip: pc2m-0.9.14/Template.inc.php <==
<?php

/* -------------------------------------------------------------------------
	!!!This file must be in Shift_JIS!!!

	HTMLo͂̃ev[g
	for PC2M Web Content Converter for Mobile Clients
	Copyright (C) 2005-2006 ucb@rcdtokyo.com
	http://www.rcdtokyo.com/pc2m/note/
------------------------------------------------------------------------- */

// ʏ㕔FORMvf
$form_adds = null;

// 摜\
if ($new_image) {

	// 摜`̑Iv_E
	if ($client->screen['gif_support']
		+ $client->screen['jpg_support']
		+ $client->screen['png_support'] > 1) {
		$form_adds .= '<select name="'.KEY_PREFIX.'t">';
		if ($client->screen['gif_support']) {
			$form_adds .= '<option value="1"'.($new_image[2] == 1 ? ' selected' : null).'>GIF';
		}
		if ($client->screen['jpg_support']) {
			$form_adds .= '<option value="2"'.($new_image[2] == 2 ? ' selected' : null).'>JPEG';
		}
		if ($client->screen['png_support']) {
			$form_adds .= '<option value="3"'.($new_image[2] == 3 ? ' selected' : null).'>PNG';
		}
		$form_adds .= '</select>';
	}

	// 掿uEEvȂǂIꍇ̃v_E̗
	// ĺAu50%v̂悤ɁA0`100̐lɁu%vL𑱂ĂB
	$form_adds .= '<select name="'.KEY_PREFIX.'q">
		<option value="">
		<option value="75%"'.($image_quality == '75%' ? ' selected' : null).'>
		<option value="50%"'.($image_quality == '50%' ? ' selected' : null).'>
		<option value="35%"'.($image_quality == '35%' ? ' selected' : null).'>
		</select><br>';

	// 摜̏cTCY̓̓tB[h
	$form_adds .= '<input type="text" name="'.
		KEY_PREFIX.'w" size="3" maxlength="3" istyle="4" value="'.$new_image[0].
		'">x<input type="text" name="'.
		KEY_PREFIX.'h" size="3" maxlength="3" istyle="4" value="'.$new_image[1].'">'.

		// 掿𐔒lœ͂ꍇ̓̓tB[h̗
		// l݂̂̓͂ł
		// ϊ̉摜`JPEGȂ͒lJPEGkƂȂ܂BL͈͂0`100łB
		// ϊ̉摜`GIF|PNGȂ͒l̓pbgFƂȂ܂BL͈͂1`256łB
		// u50%v̂悤ɁAlɁu%vL͂ł
		// ϊ̉摜`JPEGȂ͒lJPEGkƂȂ܂B
		// ϊ̉摜`GIF|PNGȂA͒lɌ摜ƑΓIȃpbgFvZ܂B
		// ̏ꍇ͂A͒l̗L͈͂0`100łB
		// 'q=<input type="text" name="'.
		// KEY_PREFIX.'q" size="2" maxlength="4" istyle="4" value="'.$image_quality.'">'.
		'<br>';

// HTML|RSS\
} else {

	// y[W̊Jn|̓̓tB[h
	if ($next_link) {
		$form_adds .= '<input type="text" name="'.KEY_PREFIX.'s" size="4" istyle="4" value="'.
		$next_trim.'">/'.number_format($total_chars).'<br>';
	}
}

// ݒʂւ̃N
$setup_link = '<a href="'.$script_self.KEY_PREFIX.'a=s'.(isset($_SESSION)? '&'.KEY_PREFIX.'u='.$_history_key: null).'"></a>';

header('Content-Type:text/html;charset=Shift_JIS');
?><html>
<head>
<meta name="robots" content="noindex, nofollow">
<title><?php echo $title ?></title>
</head>
<body<?php
if ($body_elements) {
	echo (isset($body_elements['background'])? ' background="'.$body_elements['background'].'"': null);
	echo (isset($body_elements['bgcolor'])? ' bgcolor="'.$body_elements['bgcolor'].'"': null);
	echo (isset($body_elements['text'])? ' text="'.$body_elements['text'].'"': null);
	echo (isset($body_elements['link'])? ' link="'.$body_elements['link'].'"': null);
	echo (isset($body_elements['alink'])? ' alink="'.$body_elements['alink'].'"': null);
	echo (isset($body_elements['vlink'])? ' vlink="'.$body_elements['vlink'].'"': null);
}
?>>
<form action="<?php echo basename($_SERVER['SCRIPT_NAME']) ?>"><?php echo $form_hidden ?><?php
echo ($client->dev_type == 'au')? '<a name="'.KEY_PREFIX.'t" href="#'.KEY_PREFIX.'b" accesskey="8"></a>': null ?><?php
echo ($client->dev_type == 'au')? $setup_link: null ?>
<?php echo $form_adds ?>
<input type="text" name="<?php echo KEY_PREFIX ?>u" size="4" istyle="3" value="<?php
echo $remote_url ?>"><input type="submit" value="GO"><?php
echo ($client->dev_type != 'au')? $setup_link: null ?><?php
echo ($client->dev_type != 'au')? '<a name="'.KEY_PREFIX.'t" href="#'.KEY_PREFIX.'b" accesskey="8"></a>': null ?>
</form>
<hr>
<?php echo ($rss_url? '<a href="'.$rss_url.'">RSS</a><hr>': null); ?>
<?php echo $content ?>
<hr>
<a name="<?php echo KEY_PREFIX ?>b" href="#<?php echo KEY_PREFIX ?>t" accesskey="2"></a><?php
echo $start_link? '<a href="'.$start_link.'" accesskey="1">n</a>': null ?><?php
echo $next_link? '<a href="'.$next_link.'" accesskey="9"></a>': null ?><?php
echo $copy_link? '<a href="'.$copy_link.'" accesskey="5"></a>': null ?><?php
echo $remote_url? '<a href="r.php?'.urlencode($remote_url).'"></a>': null ?><a href="mailto:-@-.ne.jp?body=<?php
echo urlencode($script_host.$_SERVER['SCRIPT_NAME'].($remote_url ? '?'.KEY_PREFIX.'u='.urlencode($remote_url): null)) ?>">F</a><?php
echo isset($_SESSION)? '<a href="'.$script_self.KEY_PREFIX.'a=h"></a>': null ?><a href="<?php
echo $script_self ?>" accesskey="6">TOP</a>

</body>
</html>

==> pc2m-0.9.15.zip: pc2m-0.9.15/Template.inc.php <==
<?php

/* -------------------------------------------------------------------------
	!!!This file must be in Shift_JIS!!!

	HTMLo͂̃ev[g
	for PC2M Web Content Converter for Mobile Clients
	Copyright (C) 2005-2006 ucb.rcdtokyo
	http://www.rcdtokyo.com/pc2m/note/
------------------------------------------------------------------------- */

// ʏ㕔FORMvf
$form_adds = null;

// 摜\
if ($new_image) {

	// 摜`̑Iv_E
	if ($client->screen['gif_support']
		+ $client->screen['jpg_support']
		+ $client->screen['png_support'] > 1) {
		$form_adds .= '<select name="'.KEY_PREFIX.'t">';
		if ($client->screen['gif_support']) {
			$form_adds .= '<option value="1"'.($new_image[2] == 1 ? ' selected' : null).'>GIF';
		}
		if ($client->screen['jpg_support']) {
			$form_adds .= '<option value="2"'.($new_image[2] == 2 ? ' selected' : null).'>JPEG';
		}
		if ($client->screen['png_support']) {
			$form_adds .= '<option value="3"'.($new_image[2] == 3 ? ' selected' : null).'>PNG';
		}
		$form_adds .= '</select>';
	}

	// 掿uEEvȂǂIꍇ̃v_E̗
	// ĺAu50%v̂悤ɁA0`100̐lɁu%vL𑱂ĂB
	$form_adds .= '<select name="'.KEY_PREFIX.'q">
		<option value="">
		<option value="75%"'.($image_quality == '75%' ? ' selected' : null).'>
		<option value="50%"'.($image_quality == '50%' ? ' selected' : null).'>
		<option value="35%"'.($image_quality == '35%' ? ' selected' : null).'>
		</select><br>';

	// 摜̏cTCY̓̓tB[h
	$form_adds .= '<input type="text" name="'.
		KEY_PREFIX.'w" size="3" maxlength="3" istyle="4" value="'.$new_image[0].
		'">x<input type="text" name="'.
		KEY_PREFIX.'h" size="3" maxlength="3" istyle="4" value="'.$new_image[1].'">'.

		// 掿𐔒lœ͂ꍇ̓̓tB[h̗
		// l݂̂̓͂ł
		// ϊ̉摜`JPEGȂ͒lJPEGkƂȂ܂BL͈͂0`100łB
		// ϊ̉摜`GIF|PNGȂ͒l̓pbgFƂȂ܂BL͈͂1`256łB
		// u50%v̂悤ɁAlɁu%vL͂ł
		// ϊ̉摜`JPEGȂ͒lJPEGkƂȂ܂B
		// ϊ̉摜`GIF|PNGȂA͒lɌ摜ƑΓIȃpbgFvZ܂B
		// ̏ꍇ͂A͒l̗L͈͂0`100łB
		// 'q=<input type="text" name="'.
		// KEY_PREFIX.'q" size="2" maxlength="4" istyle="4" value="'.$image_quality.'">'.
		'<br>';

// HTML|RSS\
} else {

	// y[W̊Jn|̓̓tB[h
	if ($next_link) {
		$form_adds .= '<input type="text" name="'.KEY_PREFIX.'s" size="4" istyle="4" value="'.
		$next_trim.'">/'.number_format($total_chars).'<br>';
	}
}

// ݒʂւ̃N
$setup_link = '<a href="'.$script_self.KEY_PREFIX.'a=s'.(isset($_SESSION)? '&'.KEY_PREFIX.'u='.$_history_key: null).'"></a>';

header('Content-Type:text/html;charset=Shift_JIS');
?><html>
<head>
<meta name="robots" content="noindex, nofollow">
<title><?php echo $title ?></title>
</head>
<body<?php
if ($body_elements) {
	echo (isset($body_elements['background'])? ' background="'.$body_elements['background'].'"': null);
	echo (isset($body_elements['bgcolor'])? ' bgcolor="'.$body_elements['bgcolor'].'"': null);
	echo (isset($body_elements['text'])? ' text="'.$body_elements['text'].'"': null);
	echo (isset($body_elements['link'])? ' link="'.$body_elements['link'].'"': null);
	echo (isset($body_elements['alink'])? ' alink="'.$body_elements['alink'].'"': null);
	echo (isset($body_elements['vlink'])? ' vlink="'.$body_elements['vlink'].'"': null);
}
?>>
<form action="<?php echo basename($_SERVER['SCRIPT_NAME']) ?>"><?php echo $form_hidden ?><?php
echo ($client->dev_type == 'au')? '<a name="'.KEY_PREFIX.'t" href="#'.KEY_PREFIX.'b" accesskey="8"></a>': null ?><?php
echo ($client->dev_type == 'au')? $setup_link: null ?>
<?php echo $form_adds ?>
<input type="text" name="<?php echo KEY_PREFIX ?>u" size="4" istyle="3" value="<?php
echo $remote_url ?>"><input type="submit" value="GO"><?php
echo ($client->dev_type != 'au')? $setup_link: null ?><?php
echo ($client->dev_type != 'au')? '<a name="'.KEY_PREFIX.'t" href="#'.KEY_PREFIX.'b" accesskey="8"></a>': null ?>
</form>
<hr>
<?php
// SĂRSStB[hւ̃NMobile Link Discovery\ꍇ̗
// $body_adds = null;
// $i = 0;
// if ($rss) {
// 	foreach ($rss as $key => $value) {
// 		if ($i > 0) {
// 			$body_adds .= '|';
// 		}
// 		$body_adds .= '<a href="'.$key.'">'.$value.'</a>';
// 		$i++;
// 	}
// }
// if ($mobile_url) {
// 	if ($body_adds) {
// 		$body_adds .= '|';
// 	}
// 	$body_adds .= '<a href="'.$mobile_url.'">gє</a>';
// }
// echo ($body_adds? $body_adds.'<hr>': null);

// uŏɌoꂽvRSStB[hւ̃N\ꍇ̗
echo $rss_url? '<a href="'.$rss_url.'">RSS</a><hr>': null;
?>
<?php echo $content ?>
<hr>
<a name="<?php echo KEY_PREFIX ?>b" href="#<?php echo KEY_PREFIX ?>t" accesskey="2"></a><?php
echo $start_link? '<a href="'.$start_link.'" accesskey="1">n</a>': null ?><?php
echo $next_link? '<a href="'.$next_link.'" accesskey="9"></a>': null ?><?php
echo $copy_link? '<a href="'.$copy_link.'" accesskey="5"></a>': null ?><?php
echo $remote_url? '<a href="r.php?'.urlencode($remote_url).'"></a>': null ?><a href="mailto:-@-.ne.jp?body=<?php
echo urlencode($script_host.$_SERVER['SCRIPT_NAME'].($remote_url ? '?'.KEY_PREFIX.'u='.urlencode($remote_url): null)) ?>">F</a><?php
echo isset($_SESSION)? '<a href="'.$script_self.KEY_PREFIX.'a=h"></a>': null ?><a href="<?php
echo $script_self ?>" accesskey="6">TOP</a>

</body>
</html>
